# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.advance_arg import AdvanceArg  # noqa: F401,E501
from demisto_client.demisto_api.models.version import Version  # noqa: F401,E501


class Reputation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cache_versn': 'int',
        'commit_message': 'str',
        'context_path': 'str',
        'context_value': 'str',
        'default_mapping': 'dict(str, AdvanceArg)',
        'definition_id': 'str',
        'details': 'str',
        'disabled': 'bool',
        'enhancement_script_names': 'list[str]',
        'excluded_brands': 'list[str]',
        'expiration': 'int',
        'file': 'bool',
        'file_hashes_priority': 'list[str]',
        'format_script': 'str',
        'from_server_version': 'Version',
        'highlight': 'dict(str, list[str])',
        'id': 'str',
        'item_version': 'Version',
        'layout': 'str',
        'legacy_names': 'list[str]',
        'locked': 'bool',
        'manual_mapping': 'dict(str, AdvanceArg)',
        'merge_context': 'bool',
        'modified': 'datetime',
        'numeric_id': 'int',
        'pack_id': 'str',
        'pack_name': 'str',
        'pack_propagation_labels': 'list[str]',
        'prev_details': 'str',
        'primary_term': 'int',
        'propagation_labels': 'list[str]',
        'regex': 'str',
        'remote': 'bool',
        'reputation_command': 'str',
        'reputation_script_name': 'str',
        'sequence_number': 'int',
        'should_commit': 'bool',
        'should_share_comments': 'bool',
        'sort_values': 'list[str]',
        'sync_hash': 'str',
        'system': 'bool',
        'to_server_version': 'Version',
        'update_after': 'int',
        'vc_should_ignore': 'bool',
        'vc_should_keep_item_legacy_prod_machine': 'bool',
        'version': 'int'
    }

    attribute_map = {
        'cache_versn': 'cacheVersn',
        'commit_message': 'commitMessage',
        'context_path': 'contextPath',
        'context_value': 'contextValue',
        'default_mapping': 'defaultMapping',
        'definition_id': 'definitionId',
        'details': 'details',
        'disabled': 'disabled',
        'enhancement_script_names': 'enhancementScriptNames',
        'excluded_brands': 'excludedBrands',
        'expiration': 'expiration',
        'file': 'file',
        'file_hashes_priority': 'fileHashesPriority',
        'format_script': 'formatScript',
        'from_server_version': 'fromServerVersion',
        'highlight': 'highlight',
        'id': 'id',
        'item_version': 'itemVersion',
        'layout': 'layout',
        'legacy_names': 'legacyNames',
        'locked': 'locked',
        'manual_mapping': 'manualMapping',
        'merge_context': 'mergeContext',
        'modified': 'modified',
        'numeric_id': 'numericId',
        'pack_id': 'packID',
        'pack_name': 'packName',
        'pack_propagation_labels': 'packPropagationLabels',
        'prev_details': 'prevDetails',
        'primary_term': 'primaryTerm',
        'propagation_labels': 'propagationLabels',
        'regex': 'regex',
        'remote': 'remote',
        'reputation_command': 'reputationCommand',
        'reputation_script_name': 'reputationScriptName',
        'sequence_number': 'sequenceNumber',
        'should_commit': 'shouldCommit',
        'should_share_comments': 'shouldShareComments',
        'sort_values': 'sortValues',
        'sync_hash': 'syncHash',
        'system': 'system',
        'to_server_version': 'toServerVersion',
        'update_after': 'updateAfter',
        'vc_should_ignore': 'vcShouldIgnore',
        'vc_should_keep_item_legacy_prod_machine': 'vcShouldKeepItemLegacyProdMachine',
        'version': 'version'
    }

    def __init__(self, cache_versn=None, commit_message=None, context_path=None, context_value=None, default_mapping=None, definition_id=None, details=None, disabled=None, enhancement_script_names=None, excluded_brands=None, expiration=None, file=None, file_hashes_priority=None, format_script=None, from_server_version=None, highlight=None, id=None, item_version=None, layout=None, legacy_names=None, locked=None, manual_mapping=None, merge_context=None, modified=None, numeric_id=None, pack_id=None, pack_name=None, pack_propagation_labels=None, prev_details=None, primary_term=None, propagation_labels=None, regex=None, remote=None, reputation_command=None, reputation_script_name=None, sequence_number=None, should_commit=None, should_share_comments=None, sort_values=None, sync_hash=None, system=None, to_server_version=None, update_after=None, vc_should_ignore=None, vc_should_keep_item_legacy_prod_machine=None, version=None):  # noqa: E501
        """Reputation - a model defined in Swagger"""  # noqa: E501

        self._cache_versn = None
        self._commit_message = None
        self._context_path = None
        self._context_value = None
        self._default_mapping = None
        self._definition_id = None
        self._details = None
        self._disabled = None
        self._enhancement_script_names = None
        self._excluded_brands = None
        self._expiration = None
        self._file = None
        self._file_hashes_priority = None
        self._format_script = None
        self._from_server_version = None
        self._highlight = None
        self._id = None
        self._item_version = None
        self._layout = None
        self._legacy_names = None
        self._locked = None
        self._manual_mapping = None
        self._merge_context = None
        self._modified = None
        self._numeric_id = None
        self._pack_id = None
        self._pack_name = None
        self._pack_propagation_labels = None
        self._prev_details = None
        self._primary_term = None
        self._propagation_labels = None
        self._regex = None
        self._remote = None
        self._reputation_command = None
        self._reputation_script_name = None
        self._sequence_number = None
        self._should_commit = None
        self._should_share_comments = None
        self._sort_values = None
        self._sync_hash = None
        self._system = None
        self._to_server_version = None
        self._update_after = None
        self._vc_should_ignore = None
        self._vc_should_keep_item_legacy_prod_machine = None
        self._version = None
        self.discriminator = None

        if cache_versn is not None:
            self.cache_versn = cache_versn
        if commit_message is not None:
            self.commit_message = commit_message
        if context_path is not None:
            self.context_path = context_path
        if context_value is not None:
            self.context_value = context_value
        if default_mapping is not None:
            self.default_mapping = default_mapping
        if definition_id is not None:
            self.definition_id = definition_id
        if details is not None:
            self.details = details
        if disabled is not None:
            self.disabled = disabled
        if enhancement_script_names is not None:
            self.enhancement_script_names = enhancement_script_names
        if excluded_brands is not None:
            self.excluded_brands = excluded_brands
        if expiration is not None:
            self.expiration = expiration
        if file is not None:
            self.file = file
        if file_hashes_priority is not None:
            self.file_hashes_priority = file_hashes_priority
        if format_script is not None:
            self.format_script = format_script
        if from_server_version is not None:
            self.from_server_version = from_server_version
        if highlight is not None:
            self.highlight = highlight
        if id is not None:
            self.id = id
        if item_version is not None:
            self.item_version = item_version
        if layout is not None:
            self.layout = layout
        if legacy_names is not None:
            self.legacy_names = legacy_names
        if locked is not None:
            self.locked = locked
        if manual_mapping is not None:
            self.manual_mapping = manual_mapping
        if merge_context is not None:
            self.merge_context = merge_context
        if modified is not None:
            self.modified = modified
        if numeric_id is not None:
            self.numeric_id = numeric_id
        if pack_id is not None:
            self.pack_id = pack_id
        if pack_name is not None:
            self.pack_name = pack_name
        if pack_propagation_labels is not None:
            self.pack_propagation_labels = pack_propagation_labels
        if prev_details is not None:
            self.prev_details = prev_details
        if primary_term is not None:
            self.primary_term = primary_term
        if propagation_labels is not None:
            self.propagation_labels = propagation_labels
        if regex is not None:
            self.regex = regex
        if remote is not None:
            self.remote = remote
        if reputation_command is not None:
            self.reputation_command = reputation_command
        if reputation_script_name is not None:
            self.reputation_script_name = reputation_script_name
        if sequence_number is not None:
            self.sequence_number = sequence_number
        if should_commit is not None:
            self.should_commit = should_commit
        if should_share_comments is not None:
            self.should_share_comments = should_share_comments
        if sort_values is not None:
            self.sort_values = sort_values
        if sync_hash is not None:
            self.sync_hash = sync_hash
        if system is not None:
            self.system = system
        if to_server_version is not None:
            self.to_server_version = to_server_version
        if update_after is not None:
            self.update_after = update_after
        if vc_should_ignore is not None:
            self.vc_should_ignore = vc_should_ignore
        if vc_should_keep_item_legacy_prod_machine is not None:
            self.vc_should_keep_item_legacy_prod_machine = vc_should_keep_item_legacy_prod_machine
        if version is not None:
            self.version = version

    @property
    def cache_versn(self):
        """Gets the cache_versn of this Reputation.  # noqa: E501


        :return: The cache_versn of this Reputation.  # noqa: E501
        :rtype: int
        """
        return self._cache_versn

    @cache_versn.setter
    def cache_versn(self, cache_versn):
        """Sets the cache_versn of this Reputation.


        :param cache_versn: The cache_versn of this Reputation.  # noqa: E501
        :type: int
        """

        self._cache_versn = cache_versn

    @property
    def commit_message(self):
        """Gets the commit_message of this Reputation.  # noqa: E501


        :return: The commit_message of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this Reputation.


        :param commit_message: The commit_message of this Reputation.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def context_path(self):
        """Gets the context_path of this Reputation.  # noqa: E501


        :return: The context_path of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._context_path

    @context_path.setter
    def context_path(self, context_path):
        """Sets the context_path of this Reputation.


        :param context_path: The context_path of this Reputation.  # noqa: E501
        :type: str
        """

        self._context_path = context_path

    @property
    def context_value(self):
        """Gets the context_value of this Reputation.  # noqa: E501


        :return: The context_value of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._context_value

    @context_value.setter
    def context_value(self, context_value):
        """Sets the context_value of this Reputation.


        :param context_value: The context_value of this Reputation.  # noqa: E501
        :type: str
        """

        self._context_value = context_value

    @property
    def default_mapping(self):
        """Gets the default_mapping of this Reputation.  # noqa: E501


        :return: The default_mapping of this Reputation.  # noqa: E501
        :rtype: dict(str, AdvanceArg)
        """
        return self._default_mapping

    @default_mapping.setter
    def default_mapping(self, default_mapping):
        """Sets the default_mapping of this Reputation.


        :param default_mapping: The default_mapping of this Reputation.  # noqa: E501
        :type: dict(str, AdvanceArg)
        """

        self._default_mapping = default_mapping

    @property
    def definition_id(self):
        """Gets the definition_id of this Reputation.  # noqa: E501


        :return: The definition_id of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._definition_id

    @definition_id.setter
    def definition_id(self, definition_id):
        """Sets the definition_id of this Reputation.


        :param definition_id: The definition_id of this Reputation.  # noqa: E501
        :type: str
        """

        self._definition_id = definition_id

    @property
    def details(self):
        """Gets the details of this Reputation.  # noqa: E501


        :return: The details of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this Reputation.


        :param details: The details of this Reputation.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def disabled(self):
        """Gets the disabled of this Reputation.  # noqa: E501


        :return: The disabled of this Reputation.  # noqa: E501
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """Sets the disabled of this Reputation.


        :param disabled: The disabled of this Reputation.  # noqa: E501
        :type: bool
        """

        self._disabled = disabled

    @property
    def enhancement_script_names(self):
        """Gets the enhancement_script_names of this Reputation.  # noqa: E501


        :return: The enhancement_script_names of this Reputation.  # noqa: E501
        :rtype: list[str]
        """
        return self._enhancement_script_names

    @enhancement_script_names.setter
    def enhancement_script_names(self, enhancement_script_names):
        """Sets the enhancement_script_names of this Reputation.


        :param enhancement_script_names: The enhancement_script_names of this Reputation.  # noqa: E501
        :type: list[str]
        """

        self._enhancement_script_names = enhancement_script_names

    @property
    def excluded_brands(self):
        """Gets the excluded_brands of this Reputation.  # noqa: E501


        :return: The excluded_brands of this Reputation.  # noqa: E501
        :rtype: list[str]
        """
        return self._excluded_brands

    @excluded_brands.setter
    def excluded_brands(self, excluded_brands):
        """Sets the excluded_brands of this Reputation.


        :param excluded_brands: The excluded_brands of this Reputation.  # noqa: E501
        :type: list[str]
        """

        self._excluded_brands = excluded_brands

    @property
    def expiration(self):
        """Gets the expiration of this Reputation.  # noqa: E501


        :return: The expiration of this Reputation.  # noqa: E501
        :rtype: int
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this Reputation.


        :param expiration: The expiration of this Reputation.  # noqa: E501
        :type: int
        """

        self._expiration = expiration

    @property
    def file(self):
        """Gets the file of this Reputation.  # noqa: E501


        :return: The file of this Reputation.  # noqa: E501
        :rtype: bool
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this Reputation.


        :param file: The file of this Reputation.  # noqa: E501
        :type: bool
        """

        self._file = file

    @property
    def file_hashes_priority(self):
        """Gets the file_hashes_priority of this Reputation.  # noqa: E501


        :return: The file_hashes_priority of this Reputation.  # noqa: E501
        :rtype: list[str]
        """
        return self._file_hashes_priority

    @file_hashes_priority.setter
    def file_hashes_priority(self, file_hashes_priority):
        """Sets the file_hashes_priority of this Reputation.


        :param file_hashes_priority: The file_hashes_priority of this Reputation.  # noqa: E501
        :type: list[str]
        """

        self._file_hashes_priority = file_hashes_priority

    @property
    def format_script(self):
        """Gets the format_script of this Reputation.  # noqa: E501


        :return: The format_script of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._format_script

    @format_script.setter
    def format_script(self, format_script):
        """Sets the format_script of this Reputation.


        :param format_script: The format_script of this Reputation.  # noqa: E501
        :type: str
        """

        self._format_script = format_script

    @property
    def from_server_version(self):
        """Gets the from_server_version of this Reputation.  # noqa: E501


        :return: The from_server_version of this Reputation.  # noqa: E501
        :rtype: Version
        """
        return self._from_server_version

    @from_server_version.setter
    def from_server_version(self, from_server_version):
        """Sets the from_server_version of this Reputation.


        :param from_server_version: The from_server_version of this Reputation.  # noqa: E501
        :type: Version
        """

        self._from_server_version = from_server_version

    @property
    def highlight(self):
        """Gets the highlight of this Reputation.  # noqa: E501


        :return: The highlight of this Reputation.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._highlight

    @highlight.setter
    def highlight(self, highlight):
        """Sets the highlight of this Reputation.


        :param highlight: The highlight of this Reputation.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._highlight = highlight

    @property
    def id(self):
        """Gets the id of this Reputation.  # noqa: E501


        :return: The id of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Reputation.


        :param id: The id of this Reputation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def item_version(self):
        """Gets the item_version of this Reputation.  # noqa: E501


        :return: The item_version of this Reputation.  # noqa: E501
        :rtype: Version
        """
        return self._item_version

    @item_version.setter
    def item_version(self, item_version):
        """Sets the item_version of this Reputation.


        :param item_version: The item_version of this Reputation.  # noqa: E501
        :type: Version
        """

        self._item_version = item_version

    @property
    def layout(self):
        """Gets the layout of this Reputation.  # noqa: E501


        :return: The layout of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._layout

    @layout.setter
    def layout(self, layout):
        """Sets the layout of this Reputation.


        :param layout: The layout of this Reputation.  # noqa: E501
        :type: str
        """

        self._layout = layout

    @property
    def legacy_names(self):
        """Gets the legacy_names of this Reputation.  # noqa: E501


        :return: The legacy_names of this Reputation.  # noqa: E501
        :rtype: list[str]
        """
        return self._legacy_names

    @legacy_names.setter
    def legacy_names(self, legacy_names):
        """Sets the legacy_names of this Reputation.


        :param legacy_names: The legacy_names of this Reputation.  # noqa: E501
        :type: list[str]
        """

        self._legacy_names = legacy_names

    @property
    def locked(self):
        """Gets the locked of this Reputation.  # noqa: E501


        :return: The locked of this Reputation.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this Reputation.


        :param locked: The locked of this Reputation.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def manual_mapping(self):
        """Gets the manual_mapping of this Reputation.  # noqa: E501


        :return: The manual_mapping of this Reputation.  # noqa: E501
        :rtype: dict(str, AdvanceArg)
        """
        return self._manual_mapping

    @manual_mapping.setter
    def manual_mapping(self, manual_mapping):
        """Sets the manual_mapping of this Reputation.


        :param manual_mapping: The manual_mapping of this Reputation.  # noqa: E501
        :type: dict(str, AdvanceArg)
        """

        self._manual_mapping = manual_mapping

    @property
    def merge_context(self):
        """Gets the merge_context of this Reputation.  # noqa: E501


        :return: The merge_context of this Reputation.  # noqa: E501
        :rtype: bool
        """
        return self._merge_context

    @merge_context.setter
    def merge_context(self, merge_context):
        """Sets the merge_context of this Reputation.


        :param merge_context: The merge_context of this Reputation.  # noqa: E501
        :type: bool
        """

        self._merge_context = merge_context

    @property
    def modified(self):
        """Gets the modified of this Reputation.  # noqa: E501


        :return: The modified of this Reputation.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Reputation.


        :param modified: The modified of this Reputation.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def numeric_id(self):
        """Gets the numeric_id of this Reputation.  # noqa: E501


        :return: The numeric_id of this Reputation.  # noqa: E501
        :rtype: int
        """
        return self._numeric_id

    @numeric_id.setter
    def numeric_id(self, numeric_id):
        """Sets the numeric_id of this Reputation.


        :param numeric_id: The numeric_id of this Reputation.  # noqa: E501
        :type: int
        """

        self._numeric_id = numeric_id

    @property
    def pack_id(self):
        """Gets the pack_id of this Reputation.  # noqa: E501


        :return: The pack_id of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._pack_id

    @pack_id.setter
    def pack_id(self, pack_id):
        """Sets the pack_id of this Reputation.


        :param pack_id: The pack_id of this Reputation.  # noqa: E501
        :type: str
        """

        self._pack_id = pack_id

    @property
    def pack_name(self):
        """Gets the pack_name of this Reputation.  # noqa: E501


        :return: The pack_name of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._pack_name

    @pack_name.setter
    def pack_name(self, pack_name):
        """Sets the pack_name of this Reputation.


        :param pack_name: The pack_name of this Reputation.  # noqa: E501
        :type: str
        """

        self._pack_name = pack_name

    @property
    def pack_propagation_labels(self):
        """Gets the pack_propagation_labels of this Reputation.  # noqa: E501


        :return: The pack_propagation_labels of this Reputation.  # noqa: E501
        :rtype: list[str]
        """
        return self._pack_propagation_labels

    @pack_propagation_labels.setter
    def pack_propagation_labels(self, pack_propagation_labels):
        """Sets the pack_propagation_labels of this Reputation.


        :param pack_propagation_labels: The pack_propagation_labels of this Reputation.  # noqa: E501
        :type: list[str]
        """

        self._pack_propagation_labels = pack_propagation_labels

    @property
    def prev_details(self):
        """Gets the prev_details of this Reputation.  # noqa: E501


        :return: The prev_details of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._prev_details

    @prev_details.setter
    def prev_details(self, prev_details):
        """Sets the prev_details of this Reputation.


        :param prev_details: The prev_details of this Reputation.  # noqa: E501
        :type: str
        """

        self._prev_details = prev_details

    @property
    def primary_term(self):
        """Gets the primary_term of this Reputation.  # noqa: E501


        :return: The primary_term of this Reputation.  # noqa: E501
        :rtype: int
        """
        return self._primary_term

    @primary_term.setter
    def primary_term(self, primary_term):
        """Sets the primary_term of this Reputation.


        :param primary_term: The primary_term of this Reputation.  # noqa: E501
        :type: int
        """

        self._primary_term = primary_term

    @property
    def propagation_labels(self):
        """Gets the propagation_labels of this Reputation.  # noqa: E501


        :return: The propagation_labels of this Reputation.  # noqa: E501
        :rtype: list[str]
        """
        return self._propagation_labels

    @propagation_labels.setter
    def propagation_labels(self, propagation_labels):
        """Sets the propagation_labels of this Reputation.


        :param propagation_labels: The propagation_labels of this Reputation.  # noqa: E501
        :type: list[str]
        """

        self._propagation_labels = propagation_labels

    @property
    def regex(self):
        """Gets the regex of this Reputation.  # noqa: E501


        :return: The regex of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._regex

    @regex.setter
    def regex(self, regex):
        """Sets the regex of this Reputation.


        :param regex: The regex of this Reputation.  # noqa: E501
        :type: str
        """

        self._regex = regex

    @property
    def remote(self):
        """Gets the remote of this Reputation.  # noqa: E501


        :return: The remote of this Reputation.  # noqa: E501
        :rtype: bool
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this Reputation.


        :param remote: The remote of this Reputation.  # noqa: E501
        :type: bool
        """

        self._remote = remote

    @property
    def reputation_command(self):
        """Gets the reputation_command of this Reputation.  # noqa: E501


        :return: The reputation_command of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._reputation_command

    @reputation_command.setter
    def reputation_command(self, reputation_command):
        """Sets the reputation_command of this Reputation.


        :param reputation_command: The reputation_command of this Reputation.  # noqa: E501
        :type: str
        """

        self._reputation_command = reputation_command

    @property
    def reputation_script_name(self):
        """Gets the reputation_script_name of this Reputation.  # noqa: E501


        :return: The reputation_script_name of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._reputation_script_name

    @reputation_script_name.setter
    def reputation_script_name(self, reputation_script_name):
        """Sets the reputation_script_name of this Reputation.


        :param reputation_script_name: The reputation_script_name of this Reputation.  # noqa: E501
        :type: str
        """

        self._reputation_script_name = reputation_script_name

    @property
    def sequence_number(self):
        """Gets the sequence_number of this Reputation.  # noqa: E501


        :return: The sequence_number of this Reputation.  # noqa: E501
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this Reputation.


        :param sequence_number: The sequence_number of this Reputation.  # noqa: E501
        :type: int
        """

        self._sequence_number = sequence_number

    @property
    def should_commit(self):
        """Gets the should_commit of this Reputation.  # noqa: E501


        :return: The should_commit of this Reputation.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this Reputation.


        :param should_commit: The should_commit of this Reputation.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def should_share_comments(self):
        """Gets the should_share_comments of this Reputation.  # noqa: E501


        :return: The should_share_comments of this Reputation.  # noqa: E501
        :rtype: bool
        """
        return self._should_share_comments

    @should_share_comments.setter
    def should_share_comments(self, should_share_comments):
        """Sets the should_share_comments of this Reputation.


        :param should_share_comments: The should_share_comments of this Reputation.  # noqa: E501
        :type: bool
        """

        self._should_share_comments = should_share_comments

    @property
    def sort_values(self):
        """Gets the sort_values of this Reputation.  # noqa: E501


        :return: The sort_values of this Reputation.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Reputation.


        :param sort_values: The sort_values of this Reputation.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def sync_hash(self):
        """Gets the sync_hash of this Reputation.  # noqa: E501


        :return: The sync_hash of this Reputation.  # noqa: E501
        :rtype: str
        """
        return self._sync_hash

    @sync_hash.setter
    def sync_hash(self, sync_hash):
        """Sets the sync_hash of this Reputation.


        :param sync_hash: The sync_hash of this Reputation.  # noqa: E501
        :type: str
        """

        self._sync_hash = sync_hash

    @property
    def system(self):
        """Gets the system of this Reputation.  # noqa: E501


        :return: The system of this Reputation.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this Reputation.


        :param system: The system of this Reputation.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def to_server_version(self):
        """Gets the to_server_version of this Reputation.  # noqa: E501


        :return: The to_server_version of this Reputation.  # noqa: E501
        :rtype: Version
        """
        return self._to_server_version

    @to_server_version.setter
    def to_server_version(self, to_server_version):
        """Sets the to_server_version of this Reputation.


        :param to_server_version: The to_server_version of this Reputation.  # noqa: E501
        :type: Version
        """

        self._to_server_version = to_server_version

    @property
    def update_after(self):
        """Gets the update_after of this Reputation.  # noqa: E501


        :return: The update_after of this Reputation.  # noqa: E501
        :rtype: int
        """
        return self._update_after

    @update_after.setter
    def update_after(self, update_after):
        """Sets the update_after of this Reputation.


        :param update_after: The update_after of this Reputation.  # noqa: E501
        :type: int
        """

        self._update_after = update_after

    @property
    def vc_should_ignore(self):
        """Gets the vc_should_ignore of this Reputation.  # noqa: E501


        :return: The vc_should_ignore of this Reputation.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_ignore

    @vc_should_ignore.setter
    def vc_should_ignore(self, vc_should_ignore):
        """Sets the vc_should_ignore of this Reputation.


        :param vc_should_ignore: The vc_should_ignore of this Reputation.  # noqa: E501
        :type: bool
        """

        self._vc_should_ignore = vc_should_ignore

    @property
    def vc_should_keep_item_legacy_prod_machine(self):
        """Gets the vc_should_keep_item_legacy_prod_machine of this Reputation.  # noqa: E501


        :return: The vc_should_keep_item_legacy_prod_machine of this Reputation.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_keep_item_legacy_prod_machine

    @vc_should_keep_item_legacy_prod_machine.setter
    def vc_should_keep_item_legacy_prod_machine(self, vc_should_keep_item_legacy_prod_machine):
        """Sets the vc_should_keep_item_legacy_prod_machine of this Reputation.


        :param vc_should_keep_item_legacy_prod_machine: The vc_should_keep_item_legacy_prod_machine of this Reputation.  # noqa: E501
        :type: bool
        """

        self._vc_should_keep_item_legacy_prod_machine = vc_should_keep_item_legacy_prod_machine

    @property
    def version(self):
        """Gets the version of this Reputation.  # noqa: E501


        :return: The version of this Reputation.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Reputation.


        :param version: The version of this Reputation.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Reputation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Reputation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.feed_indicators import FeedIndicators  # noqa: F401,E501
from demisto_client.demisto_api.models.incidents import Incidents  # noqa: F401,E501
from demisto_client.demisto_api.models.mapper import Mapper  # noqa: F401,E501
from demisto_client.demisto_api.models.version import Version  # noqa: F401,E501


class InstanceClassifier(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'brand_name': 'str',
        'commit_message': 'str',
        'custom': 'bool',
        'default_incident_type': 'str',
        'feed': 'bool',
        'from_server_version': 'Version',
        'id': 'str',
        'incident_samples': 'Incidents',
        'indicator_samples': 'FeedIndicators',
        'instance_id': 'str',
        'instance_name': 'str',
        'is_default': 'bool',
        'item_version': 'Version',
        'key_type_map': 'dict(str, str)',
        'mapping': 'dict(str, Mapper)',
        'modified': 'datetime',
        'pack_id': 'str',
        'primary_term': 'int',
        'propagation_labels': 'list[str]',
        'sequence_number': 'int',
        'should_commit': 'bool',
        'sort_values': 'list[str]',
        'version': 'int'
    }

    attribute_map = {
        'brand_name': 'brandName',
        'commit_message': 'commitMessage',
        'custom': 'custom',
        'default_incident_type': 'defaultIncidentType',
        'feed': 'feed',
        'from_server_version': 'fromServerVersion',
        'id': 'id',
        'incident_samples': 'incidentSamples',
        'indicator_samples': 'indicatorSamples',
        'instance_id': 'instanceId',
        'instance_name': 'instanceName',
        'is_default': 'isDefault',
        'item_version': 'itemVersion',
        'key_type_map': 'keyTypeMap',
        'mapping': 'mapping',
        'modified': 'modified',
        'pack_id': 'packID',
        'primary_term': 'primaryTerm',
        'propagation_labels': 'propagationLabels',
        'sequence_number': 'sequenceNumber',
        'should_commit': 'shouldCommit',
        'sort_values': 'sortValues',
        'version': 'version'
    }

    def __init__(self, brand_name=None, commit_message=None, custom=None, default_incident_type=None, feed=None, from_server_version=None, id=None, incident_samples=None, indicator_samples=None, instance_id=None, instance_name=None, is_default=None, item_version=None, key_type_map=None, mapping=None, modified=None, pack_id=None, primary_term=None, propagation_labels=None, sequence_number=None, should_commit=None, sort_values=None, version=None):  # noqa: E501
        """InstanceClassifier - a model defined in Swagger"""  # noqa: E501

        self._brand_name = None
        self._commit_message = None
        self._custom = None
        self._default_incident_type = None
        self._feed = None
        self._from_server_version = None
        self._id = None
        self._incident_samples = None
        self._indicator_samples = None
        self._instance_id = None
        self._instance_name = None
        self._is_default = None
        self._item_version = None
        self._key_type_map = None
        self._mapping = None
        self._modified = None
        self._pack_id = None
        self._primary_term = None
        self._propagation_labels = None
        self._sequence_number = None
        self._should_commit = None
        self._sort_values = None
        self._version = None
        self.discriminator = None

        if brand_name is not None:
            self.brand_name = brand_name
        if commit_message is not None:
            self.commit_message = commit_message
        if custom is not None:
            self.custom = custom
        if default_incident_type is not None:
            self.default_incident_type = default_incident_type
        if feed is not None:
            self.feed = feed
        if from_server_version is not None:
            self.from_server_version = from_server_version
        if id is not None:
            self.id = id
        if incident_samples is not None:
            self.incident_samples = incident_samples
        if indicator_samples is not None:
            self.indicator_samples = indicator_samples
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_name is not None:
            self.instance_name = instance_name
        if is_default is not None:
            self.is_default = is_default
        if item_version is not None:
            self.item_version = item_version
        if key_type_map is not None:
            self.key_type_map = key_type_map
        if mapping is not None:
            self.mapping = mapping
        if modified is not None:
            self.modified = modified
        if pack_id is not None:
            self.pack_id = pack_id
        if primary_term is not None:
            self.primary_term = primary_term
        if propagation_labels is not None:
            self.propagation_labels = propagation_labels
        if sequence_number is not None:
            self.sequence_number = sequence_number
        if should_commit is not None:
            self.should_commit = should_commit
        if sort_values is not None:
            self.sort_values = sort_values
        if version is not None:
            self.version = version

    @property
    def brand_name(self):
        """Gets the brand_name of this InstanceClassifier.  # noqa: E501


        :return: The brand_name of this InstanceClassifier.  # noqa: E501
        :rtype: str
        """
        return self._brand_name

    @brand_name.setter
    def brand_name(self, brand_name):
        """Sets the brand_name of this InstanceClassifier.


        :param brand_name: The brand_name of this InstanceClassifier.  # noqa: E501
        :type: str
        """

        self._brand_name = brand_name

    @property
    def commit_message(self):
        """Gets the commit_message of this InstanceClassifier.  # noqa: E501


        :return: The commit_message of this InstanceClassifier.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this InstanceClassifier.


        :param commit_message: The commit_message of this InstanceClassifier.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def custom(self):
        """Gets the custom of this InstanceClassifier.  # noqa: E501


        :return: The custom of this InstanceClassifier.  # noqa: E501
        :rtype: bool
        """
        return self._custom

    @custom.setter
    def custom(self, custom):
        """Sets the custom of this InstanceClassifier.


        :param custom: The custom of this InstanceClassifier.  # noqa: E501
        :type: bool
        """

        self._custom = custom

    @property
    def default_incident_type(self):
        """Gets the default_incident_type of this InstanceClassifier.  # noqa: E501


        :return: The default_incident_type of this InstanceClassifier.  # noqa: E501
        :rtype: str
        """
        return self._default_incident_type

    @default_incident_type.setter
    def default_incident_type(self, default_incident_type):
        """Sets the default_incident_type of this InstanceClassifier.


        :param default_incident_type: The default_incident_type of this InstanceClassifier.  # noqa: E501
        :type: str
        """

        self._default_incident_type = default_incident_type

    @property
    def feed(self):
        """Gets the feed of this InstanceClassifier.  # noqa: E501


        :return: The feed of this InstanceClassifier.  # noqa: E501
        :rtype: bool
        """
        return self._feed

    @feed.setter
    def feed(self, feed):
        """Sets the feed of this InstanceClassifier.


        :param feed: The feed of this InstanceClassifier.  # noqa: E501
        :type: bool
        """

        self._feed = feed

    @property
    def from_server_version(self):
        """Gets the from_server_version of this InstanceClassifier.  # noqa: E501


        :return: The from_server_version of this InstanceClassifier.  # noqa: E501
        :rtype: Version
        """
        return self._from_server_version

    @from_server_version.setter
    def from_server_version(self, from_server_version):
        """Sets the from_server_version of this InstanceClassifier.


        :param from_server_version: The from_server_version of this InstanceClassifier.  # noqa: E501
        :type: Version
        """

        self._from_server_version = from_server_version

    @property
    def id(self):
        """Gets the id of this InstanceClassifier.  # noqa: E501


        :return: The id of this InstanceClassifier.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InstanceClassifier.


        :param id: The id of this InstanceClassifier.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def incident_samples(self):
        """Gets the incident_samples of this InstanceClassifier.  # noqa: E501


        :return: The incident_samples of this InstanceClassifier.  # noqa: E501
        :rtype: Incidents
        """
        return self._incident_samples

    @incident_samples.setter
    def incident_samples(self, incident_samples):
        """Sets the incident_samples of this InstanceClassifier.


        :param incident_samples: The incident_samples of this InstanceClassifier.  # noqa: E501
        :type: Incidents
        """

        self._incident_samples = incident_samples

    @property
    def indicator_samples(self):
        """Gets the indicator_samples of this InstanceClassifier.  # noqa: E501


        :return: The indicator_samples of this InstanceClassifier.  # noqa: E501
        :rtype: FeedIndicators
        """
        return self._indicator_samples

    @indicator_samples.setter
    def indicator_samples(self, indicator_samples):
        """Sets the indicator_samples of this InstanceClassifier.


        :param indicator_samples: The indicator_samples of this InstanceClassifier.  # noqa: E501
        :type: FeedIndicators
        """

        self._indicator_samples = indicator_samples

    @property
    def instance_id(self):
        """Gets the instance_id of this InstanceClassifier.  # noqa: E501


        :return: The instance_id of this InstanceClassifier.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this InstanceClassifier.


        :param instance_id: The instance_id of this InstanceClassifier.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_name(self):
        """Gets the instance_name of this InstanceClassifier.  # noqa: E501


        :return: The instance_name of this InstanceClassifier.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this InstanceClassifier.


        :param instance_name: The instance_name of this InstanceClassifier.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def is_default(self):
        """Gets the is_default of this InstanceClassifier.  # noqa: E501


        :return: The is_default of this InstanceClassifier.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this InstanceClassifier.


        :param is_default: The is_default of this InstanceClassifier.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def item_version(self):
        """Gets the item_version of this InstanceClassifier.  # noqa: E501


        :return: The item_version of this InstanceClassifier.  # noqa: E501
        :rtype: Version
        """
        return self._item_version

    @item_version.setter
    def item_version(self, item_version):
        """Sets the item_version of this InstanceClassifier.


        :param item_version: The item_version of this InstanceClassifier.  # noqa: E501
        :type: Version
        """

        self._item_version = item_version

    @property
    def key_type_map(self):
        """Gets the key_type_map of this InstanceClassifier.  # noqa: E501


        :return: The key_type_map of this InstanceClassifier.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._key_type_map

    @key_type_map.setter
    def key_type_map(self, key_type_map):
        """Sets the key_type_map of this InstanceClassifier.


        :param key_type_map: The key_type_map of this InstanceClassifier.  # noqa: E501
        :type: dict(str, str)
        """

        self._key_type_map = key_type_map

    @property
    def mapping(self):
        """Gets the mapping of this InstanceClassifier.  # noqa: E501


        :return: The mapping of this InstanceClassifier.  # noqa: E501
        :rtype: dict(str, Mapper)
        """
        return self._mapping

    @mapping.setter
    def mapping(self, mapping):
        """Sets the mapping of this InstanceClassifier.


        :param mapping: The mapping of this InstanceClassifier.  # noqa: E501
        :type: dict(str, Mapper)
        """

        self._mapping = mapping

    @property
    def modified(self):
        """Gets the modified of this InstanceClassifier.  # noqa: E501


        :return: The modified of this InstanceClassifier.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this InstanceClassifier.


        :param modified: The modified of this InstanceClassifier.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def pack_id(self):
        """Gets the pack_id of this InstanceClassifier.  # noqa: E501


        :return: The pack_id of this InstanceClassifier.  # noqa: E501
        :rtype: str
        """
        return self._pack_id

    @pack_id.setter
    def pack_id(self, pack_id):
        """Sets the pack_id of this InstanceClassifier.


        :param pack_id: The pack_id of this InstanceClassifier.  # noqa: E501
        :type: str
        """

        self._pack_id = pack_id

    @property
    def primary_term(self):
        """Gets the primary_term of this InstanceClassifier.  # noqa: E501


        :return: The primary_term of this InstanceClassifier.  # noqa: E501
        :rtype: int
        """
        return self._primary_term

    @primary_term.setter
    def primary_term(self, primary_term):
        """Sets the primary_term of this InstanceClassifier.


        :param primary_term: The primary_term of this InstanceClassifier.  # noqa: E501
        :type: int
        """

        self._primary_term = primary_term

    @property
    def propagation_labels(self):
        """Gets the propagation_labels of this InstanceClassifier.  # noqa: E501


        :return: The propagation_labels of this InstanceClassifier.  # noqa: E501
        :rtype: list[str]
        """
        return self._propagation_labels

    @propagation_labels.setter
    def propagation_labels(self, propagation_labels):
        """Sets the propagation_labels of this InstanceClassifier.


        :param propagation_labels: The propagation_labels of this InstanceClassifier.  # noqa: E501
        :type: list[str]
        """

        self._propagation_labels = propagation_labels

    @property
    def sequence_number(self):
        """Gets the sequence_number of this InstanceClassifier.  # noqa: E501


        :return: The sequence_number of this InstanceClassifier.  # noqa: E501
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this InstanceClassifier.


        :param sequence_number: The sequence_number of this InstanceClassifier.  # noqa: E501
        :type: int
        """

        self._sequence_number = sequence_number

    @property
    def should_commit(self):
        """Gets the should_commit of this InstanceClassifier.  # noqa: E501


        :return: The should_commit of this InstanceClassifier.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this InstanceClassifier.


        :param should_commit: The should_commit of this InstanceClassifier.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def sort_values(self):
        """Gets the sort_values of this InstanceClassifier.  # noqa: E501


        :return: The sort_values of this InstanceClassifier.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this InstanceClassifier.


        :param sort_values: The sort_values of this InstanceClassifier.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def version(self):
        """Gets the version of this InstanceClassifier.  # noqa: E501


        :return: The version of this InstanceClassifier.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InstanceClassifier.


        :param version: The version of this InstanceClassifier.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstanceClassifier, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstanceClassifier):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.ending_type import EndingType  # noqa: F401,E501
from demisto_client.demisto_api.models.entry_category import EntryCategory  # noqa: F401,E501
from demisto_client.demisto_api.models.entry_history import EntryHistory  # noqa: F401,E501
from demisto_client.demisto_api.models.entry_reputation import EntryReputation  # noqa: F401,E501
from demisto_client.demisto_api.models.entry_task import EntryTask  # noqa: F401,E501
from demisto_client.demisto_api.models.entry_type import EntryType  # noqa: F401,E501
from demisto_client.demisto_api.models.file_metadata import FileMetadata  # noqa: F401,E501
from demisto_client.demisto_api.models.human_cron import HumanCron  # noqa: F401,E501


class Entry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'shard_id': 'int',
        'brand': 'str',
        'category': 'EntryCategory',
        'contents': 'object',
        'contents_size': 'int',
        'created': 'datetime',
        'cron': 'str',
        'cron_view': 'bool',
        'deleted': 'bool',
        'ending_date': 'datetime',
        'ending_type': 'EndingType',
        'entry_task': 'EntryTask',
        'error_source': 'str',
        'file': 'str',
        'file_id': 'str',
        'file_metadata': 'FileMetadata',
        'format': 'str',
        'has_role': 'bool',
        'history': 'list[EntryHistory]',
        'human_cron': 'HumanCron',
        'id': 'str',
        'instance': 'str',
        'investigation_id': 'str',
        'modified': 'datetime',
        'note': 'bool',
        'parent_content': 'object',
        'parent_entry_truncated': 'bool',
        'parent_id': 'str',
        'pinned': 'bool',
        'playbook_id': 'str',
        'previous_roles': 'list[str]',
        'read_only': 'bool',
        'recurrent': 'bool',
        'reputation_size': 'int',
        'reputations': 'list[EntryReputation]',
        'roles': 'list[str]',
        'scheduled': 'bool',
        'sort_values': 'list[str]',
        'start_date': 'datetime',
        'system': 'str',
        'tags': 'list[str]',
        'tags_raw': 'list[str]',
        'task_id': 'str',
        'times': 'int',
        'timezone_offset': 'int',
        'type': 'EntryType',
        'user': 'str',
        'version': 'int'
    }

    attribute_map = {
        'shard_id': 'ShardID',
        'brand': 'brand',
        'category': 'category',
        'contents': 'contents',
        'contents_size': 'contentsSize',
        'created': 'created',
        'cron': 'cron',
        'cron_view': 'cronView',
        'deleted': 'deleted',
        'ending_date': 'endingDate',
        'ending_type': 'endingType',
        'entry_task': 'entryTask',
        'error_source': 'errorSource',
        'file': 'file',
        'file_id': 'fileID',
        'file_metadata': 'fileMetadata',
        'format': 'format',
        'has_role': 'hasRole',
        'history': 'history',
        'human_cron': 'humanCron',
        'id': 'id',
        'instance': 'instance',
        'investigation_id': 'investigationId',
        'modified': 'modified',
        'note': 'note',
        'parent_content': 'parentContent',
        'parent_entry_truncated': 'parentEntryTruncated',
        'parent_id': 'parentId',
        'pinned': 'pinned',
        'playbook_id': 'playbookId',
        'previous_roles': 'previousRoles',
        'read_only': 'readOnly',
        'recurrent': 'recurrent',
        'reputation_size': 'reputationSize',
        'reputations': 'reputations',
        'roles': 'roles',
        'scheduled': 'scheduled',
        'sort_values': 'sortValues',
        'start_date': 'startDate',
        'system': 'system',
        'tags': 'tags',
        'tags_raw': 'tagsRaw',
        'task_id': 'taskId',
        'times': 'times',
        'timezone_offset': 'timezoneOffset',
        'type': 'type',
        'user': 'user',
        'version': 'version'
    }

    def __init__(self, shard_id=None, brand=None, category=None, contents=None, contents_size=None, created=None, cron=None, cron_view=None, deleted=None, ending_date=None, ending_type=None, entry_task=None, error_source=None, file=None, file_id=None, file_metadata=None, format=None, has_role=None, history=None, human_cron=None, id=None, instance=None, investigation_id=None, modified=None, note=None, parent_content=None, parent_entry_truncated=None, parent_id=None, pinned=None, playbook_id=None, previous_roles=None, read_only=None, recurrent=None, reputation_size=None, reputations=None, roles=None, scheduled=None, sort_values=None, start_date=None, system=None, tags=None, tags_raw=None, task_id=None, times=None, timezone_offset=None, type=None, user=None, version=None):  # noqa: E501
        """Entry - a model defined in Swagger"""  # noqa: E501

        self._shard_id = None
        self._brand = None
        self._category = None
        self._contents = None
        self._contents_size = None
        self._created = None
        self._cron = None
        self._cron_view = None
        self._deleted = None
        self._ending_date = None
        self._ending_type = None
        self._entry_task = None
        self._error_source = None
        self._file = None
        self._file_id = None
        self._file_metadata = None
        self._format = None
        self._has_role = None
        self._history = None
        self._human_cron = None
        self._id = None
        self._instance = None
        self._investigation_id = None
        self._modified = None
        self._note = None
        self._parent_content = None
        self._parent_entry_truncated = None
        self._parent_id = None
        self._pinned = None
        self._playbook_id = None
        self._previous_roles = None
        self._read_only = None
        self._recurrent = None
        self._reputation_size = None
        self._reputations = None
        self._roles = None
        self._scheduled = None
        self._sort_values = None
        self._start_date = None
        self._system = None
        self._tags = None
        self._tags_raw = None
        self._task_id = None
        self._times = None
        self._timezone_offset = None
        self._type = None
        self._user = None
        self._version = None
        self.discriminator = None

        if shard_id is not None:
            self.shard_id = shard_id
        if brand is not None:
            self.brand = brand
        if category is not None:
            self.category = category
        if contents is not None:
            self.contents = contents
        if contents_size is not None:
            self.contents_size = contents_size
        if created is not None:
            self.created = created
        if cron is not None:
            self.cron = cron
        if cron_view is not None:
            self.cron_view = cron_view
        if deleted is not None:
            self.deleted = deleted
        if ending_date is not None:
            self.ending_date = ending_date
        if ending_type is not None:
            self.ending_type = ending_type
        if entry_task is not None:
            self.entry_task = entry_task
        if error_source is not None:
            self.error_source = error_source
        if file is not None:
            self.file = file
        if file_id is not None:
            self.file_id = file_id
        if file_metadata is not None:
            self.file_metadata = file_metadata
        if format is not None:
            self.format = format
        if has_role is not None:
            self.has_role = has_role
        if history is not None:
            self.history = history
        if human_cron is not None:
            self.human_cron = human_cron
        if id is not None:
            self.id = id
        if instance is not None:
            self.instance = instance
        if investigation_id is not None:
            self.investigation_id = investigation_id
        if modified is not None:
            self.modified = modified
        if note is not None:
            self.note = note
        if parent_content is not None:
            self.parent_content = parent_content
        if parent_entry_truncated is not None:
            self.parent_entry_truncated = parent_entry_truncated
        if parent_id is not None:
            self.parent_id = parent_id
        if pinned is not None:
            self.pinned = pinned
        if playbook_id is not None:
            self.playbook_id = playbook_id
        if previous_roles is not None:
            self.previous_roles = previous_roles
        if read_only is not None:
            self.read_only = read_only
        if recurrent is not None:
            self.recurrent = recurrent
        if reputation_size is not None:
            self.reputation_size = reputation_size
        if reputations is not None:
            self.reputations = reputations
        if roles is not None:
            self.roles = roles
        if scheduled is not None:
            self.scheduled = scheduled
        if sort_values is not None:
            self.sort_values = sort_values
        if start_date is not None:
            self.start_date = start_date
        if system is not None:
            self.system = system
        if tags is not None:
            self.tags = tags
        if tags_raw is not None:
            self.tags_raw = tags_raw
        if task_id is not None:
            self.task_id = task_id
        if times is not None:
            self.times = times
        if timezone_offset is not None:
            self.timezone_offset = timezone_offset
        if type is not None:
            self.type = type
        if user is not None:
            self.user = user
        if version is not None:
            self.version = version

    @property
    def shard_id(self):
        """Gets the shard_id of this Entry.  # noqa: E501


        :return: The shard_id of this Entry.  # noqa: E501
        :rtype: int
        """
        return self._shard_id

    @shard_id.setter
    def shard_id(self, shard_id):
        """Sets the shard_id of this Entry.


        :param shard_id: The shard_id of this Entry.  # noqa: E501
        :type: int
        """

        self._shard_id = shard_id

    @property
    def brand(self):
        """Gets the brand of this Entry.  # noqa: E501


        :return: The brand of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this Entry.


        :param brand: The brand of this Entry.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def category(self):
        """Gets the category of this Entry.  # noqa: E501


        :return: The category of this Entry.  # noqa: E501
        :rtype: EntryCategory
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Entry.


        :param category: The category of this Entry.  # noqa: E501
        :type: EntryCategory
        """

        self._category = category

    @property
    def contents(self):
        """Gets the contents of this Entry.  # noqa: E501

        The contents of the entry that is actually indexed - should not be used  # noqa: E501

        :return: The contents of this Entry.  # noqa: E501
        :rtype: object
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """Sets the contents of this Entry.

        The contents of the entry that is actually indexed - should not be used  # noqa: E501

        :param contents: The contents of this Entry.  # noqa: E501
        :type: object
        """

        self._contents = contents

    @property
    def contents_size(self):
        """Gets the contents_size of this Entry.  # noqa: E501

        ContentsSize the total size of the contents  # noqa: E501

        :return: The contents_size of this Entry.  # noqa: E501
        :rtype: int
        """
        return self._contents_size

    @contents_size.setter
    def contents_size(self, contents_size):
        """Sets the contents_size of this Entry.

        ContentsSize the total size of the contents  # noqa: E501

        :param contents_size: The contents_size of this Entry.  # noqa: E501
        :type: int
        """

        self._contents_size = contents_size

    @property
    def created(self):
        """Gets the created of this Entry.  # noqa: E501

        When it was taken  # noqa: E501

        :return: The created of this Entry.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Entry.

        When it was taken  # noqa: E501

        :param created: The created of this Entry.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def cron(self):
        """Gets the cron of this Entry.  # noqa: E501


        :return: The cron of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._cron

    @cron.setter
    def cron(self, cron):
        """Sets the cron of this Entry.


        :param cron: The cron of this Entry.  # noqa: E501
        :type: str
        """

        self._cron = cron

    @property
    def cron_view(self):
        """Gets the cron_view of this Entry.  # noqa: E501


        :return: The cron_view of this Entry.  # noqa: E501
        :rtype: bool
        """
        return self._cron_view

    @cron_view.setter
    def cron_view(self, cron_view):
        """Sets the cron_view of this Entry.


        :param cron_view: The cron_view of this Entry.  # noqa: E501
        :type: bool
        """

        self._cron_view = cron_view

    @property
    def deleted(self):
        """Gets the deleted of this Entry.  # noqa: E501


        :return: The deleted of this Entry.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this Entry.


        :param deleted: The deleted of this Entry.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def ending_date(self):
        """Gets the ending_date of this Entry.  # noqa: E501


        :return: The ending_date of this Entry.  # noqa: E501
        :rtype: datetime
        """
        return self._ending_date

    @ending_date.setter
    def ending_date(self, ending_date):
        """Sets the ending_date of this Entry.


        :param ending_date: The ending_date of this Entry.  # noqa: E501
        :type: datetime
        """

        self._ending_date = ending_date

    @property
    def ending_type(self):
        """Gets the ending_type of this Entry.  # noqa: E501


        :return: The ending_type of this Entry.  # noqa: E501
        :rtype: EndingType
        """
        return self._ending_type

    @ending_type.setter
    def ending_type(self, ending_type):
        """Sets the ending_type of this Entry.


        :param ending_type: The ending_type of this Entry.  # noqa: E501
        :type: EndingType
        """

        self._ending_type = ending_type

    @property
    def entry_task(self):
        """Gets the entry_task of this Entry.  # noqa: E501


        :return: The entry_task of this Entry.  # noqa: E501
        :rtype: EntryTask
        """
        return self._entry_task

    @entry_task.setter
    def entry_task(self, entry_task):
        """Sets the entry_task of this Entry.


        :param entry_task: The entry_task of this Entry.  # noqa: E501
        :type: EntryTask
        """

        self._entry_task = entry_task

    @property
    def error_source(self):
        """Gets the error_source of this Entry.  # noqa: E501

        Source of the error  # noqa: E501

        :return: The error_source of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._error_source

    @error_source.setter
    def error_source(self, error_source):
        """Sets the error_source of this Entry.

        Source of the error  # noqa: E501

        :param error_source: The error_source of this Entry.  # noqa: E501
        :type: str
        """

        self._error_source = error_source

    @property
    def file(self):
        """Gets the file of this Entry.  # noqa: E501

        Filename of associated content  # noqa: E501

        :return: The file of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this Entry.

        Filename of associated content  # noqa: E501

        :param file: The file of this Entry.  # noqa: E501
        :type: str
        """

        self._file = file

    @property
    def file_id(self):
        """Gets the file_id of this Entry.  # noqa: E501

        FileID is the file name when saved in the server  # noqa: E501

        :return: The file_id of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """Sets the file_id of this Entry.

        FileID is the file name when saved in the server  # noqa: E501

        :param file_id: The file_id of this Entry.  # noqa: E501
        :type: str
        """

        self._file_id = file_id

    @property
    def file_metadata(self):
        """Gets the file_metadata of this Entry.  # noqa: E501


        :return: The file_metadata of this Entry.  # noqa: E501
        :rtype: FileMetadata
        """
        return self._file_metadata

    @file_metadata.setter
    def file_metadata(self, file_metadata):
        """Sets the file_metadata of this Entry.


        :param file_metadata: The file_metadata of this Entry.  # noqa: E501
        :type: FileMetadata
        """

        self._file_metadata = file_metadata

    @property
    def format(self):
        """Gets the format of this Entry.  # noqa: E501

        Holds information on how content is formatted  # noqa: E501

        :return: The format of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this Entry.

        Holds information on how content is formatted  # noqa: E501

        :param format: The format of this Entry.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def has_role(self):
        """Gets the has_role of this Entry.  # noqa: E501

        Internal field to make queries on role faster  # noqa: E501

        :return: The has_role of this Entry.  # noqa: E501
        :rtype: bool
        """
        return self._has_role

    @has_role.setter
    def has_role(self, has_role):
        """Sets the has_role of this Entry.

        Internal field to make queries on role faster  # noqa: E501

        :param has_role: The has_role of this Entry.  # noqa: E501
        :type: bool
        """

        self._has_role = has_role

    @property
    def history(self):
        """Gets the history of this Entry.  # noqa: E501

        Edit history  # noqa: E501

        :return: The history of this Entry.  # noqa: E501
        :rtype: list[EntryHistory]
        """
        return self._history

    @history.setter
    def history(self, history):
        """Sets the history of this Entry.

        Edit history  # noqa: E501

        :param history: The history of this Entry.  # noqa: E501
        :type: list[EntryHistory]
        """

        self._history = history

    @property
    def human_cron(self):
        """Gets the human_cron of this Entry.  # noqa: E501


        :return: The human_cron of this Entry.  # noqa: E501
        :rtype: HumanCron
        """
        return self._human_cron

    @human_cron.setter
    def human_cron(self, human_cron):
        """Sets the human_cron of this Entry.


        :param human_cron: The human_cron of this Entry.  # noqa: E501
        :type: HumanCron
        """

        self._human_cron = human_cron

    @property
    def id(self):
        """Gets the id of this Entry.  # noqa: E501


        :return: The id of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Entry.


        :param id: The id of this Entry.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def instance(self):
        """Gets the instance of this Entry.  # noqa: E501


        :return: The instance of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._instance

    @instance.setter
    def instance(self, instance):
        """Sets the instance of this Entry.


        :param instance: The instance of this Entry.  # noqa: E501
        :type: str
        """

        self._instance = instance

    @property
    def investigation_id(self):
        """Gets the investigation_id of this Entry.  # noqa: E501

        The id of the investigation it belongs to  # noqa: E501

        :return: The investigation_id of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._investigation_id

    @investigation_id.setter
    def investigation_id(self, investigation_id):
        """Sets the investigation_id of this Entry.

        The id of the investigation it belongs to  # noqa: E501

        :param investigation_id: The investigation_id of this Entry.  # noqa: E501
        :type: str
        """

        self._investigation_id = investigation_id

    @property
    def modified(self):
        """Gets the modified of this Entry.  # noqa: E501


        :return: The modified of this Entry.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Entry.


        :param modified: The modified of this Entry.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def note(self):
        """Gets the note of this Entry.  # noqa: E501

        Note  # noqa: E501

        :return: The note of this Entry.  # noqa: E501
        :rtype: bool
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this Entry.

        Note  # noqa: E501

        :param note: The note of this Entry.  # noqa: E501
        :type: bool
        """

        self._note = note

    @property
    def parent_content(self):
        """Gets the parent_content of this Entry.  # noqa: E501

        ParentEntry content - for reference  # noqa: E501

        :return: The parent_content of this Entry.  # noqa: E501
        :rtype: object
        """
        return self._parent_content

    @parent_content.setter
    def parent_content(self, parent_content):
        """Sets the parent_content of this Entry.

        ParentEntry content - for reference  # noqa: E501

        :param parent_content: The parent_content of this Entry.  # noqa: E501
        :type: object
        """

        self._parent_content = parent_content

    @property
    def parent_entry_truncated(self):
        """Gets the parent_entry_truncated of this Entry.  # noqa: E501

        ParentEntryTruncated - indicates weather entry content was truncated  # noqa: E501

        :return: The parent_entry_truncated of this Entry.  # noqa: E501
        :rtype: bool
        """
        return self._parent_entry_truncated

    @parent_entry_truncated.setter
    def parent_entry_truncated(self, parent_entry_truncated):
        """Sets the parent_entry_truncated of this Entry.

        ParentEntryTruncated - indicates weather entry content was truncated  # noqa: E501

        :param parent_entry_truncated: The parent_entry_truncated of this Entry.  # noqa: E501
        :type: bool
        """

        self._parent_entry_truncated = parent_entry_truncated

    @property
    def parent_id(self):
        """Gets the parent_id of this Entry.  # noqa: E501

        ParentId is the ID of the parent entry  # noqa: E501

        :return: The parent_id of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this Entry.

        ParentId is the ID of the parent entry  # noqa: E501

        :param parent_id: The parent_id of this Entry.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def pinned(self):
        """Gets the pinned of this Entry.  # noqa: E501

        Mark entry as pinned = evidence  # noqa: E501

        :return: The pinned of this Entry.  # noqa: E501
        :rtype: bool
        """
        return self._pinned

    @pinned.setter
    def pinned(self, pinned):
        """Sets the pinned of this Entry.

        Mark entry as pinned = evidence  # noqa: E501

        :param pinned: The pinned of this Entry.  # noqa: E501
        :type: bool
        """

        self._pinned = pinned

    @property
    def playbook_id(self):
        """Gets the playbook_id of this Entry.  # noqa: E501

        PlaybookID - if the entry is assigned as note to a playbook task, it will hold the playbook  # noqa: E501

        :return: The playbook_id of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._playbook_id

    @playbook_id.setter
    def playbook_id(self, playbook_id):
        """Sets the playbook_id of this Entry.

        PlaybookID - if the entry is assigned as note to a playbook task, it will hold the playbook  # noqa: E501

        :param playbook_id: The playbook_id of this Entry.  # noqa: E501
        :type: str
        """

        self._playbook_id = playbook_id

    @property
    def previous_roles(self):
        """Gets the previous_roles of this Entry.  # noqa: E501

        PreviousRoleName - do not change this field manually  # noqa: E501

        :return: The previous_roles of this Entry.  # noqa: E501
        :rtype: list[str]
        """
        return self._previous_roles

    @previous_roles.setter
    def previous_roles(self, previous_roles):
        """Sets the previous_roles of this Entry.

        PreviousRoleName - do not change this field manually  # noqa: E501

        :param previous_roles: The previous_roles of this Entry.  # noqa: E501
        :type: list[str]
        """

        self._previous_roles = previous_roles

    @property
    def read_only(self):
        """Gets the read_only of this Entry.  # noqa: E501

        ReadOnly  # noqa: E501

        :return: The read_only of this Entry.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this Entry.

        ReadOnly  # noqa: E501

        :param read_only: The read_only of this Entry.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def recurrent(self):
        """Gets the recurrent of this Entry.  # noqa: E501


        :return: The recurrent of this Entry.  # noqa: E501
        :rtype: bool
        """
        return self._recurrent

    @recurrent.setter
    def recurrent(self, recurrent):
        """Sets the recurrent of this Entry.


        :param recurrent: The recurrent of this Entry.  # noqa: E501
        :type: bool
        """

        self._recurrent = recurrent

    @property
    def reputation_size(self):
        """Gets the reputation_size of this Entry.  # noqa: E501

        ReputationSize the total size of the reputation  # noqa: E501

        :return: The reputation_size of this Entry.  # noqa: E501
        :rtype: int
        """
        return self._reputation_size

    @reputation_size.setter
    def reputation_size(self, reputation_size):
        """Sets the reputation_size of this Entry.

        ReputationSize the total size of the reputation  # noqa: E501

        :param reputation_size: The reputation_size of this Entry.  # noqa: E501
        :type: int
        """

        self._reputation_size = reputation_size

    @property
    def reputations(self):
        """Gets the reputations of this Entry.  # noqa: E501

        EntryReputations the reputations calculated by regex match  # noqa: E501

        :return: The reputations of this Entry.  # noqa: E501
        :rtype: list[EntryReputation]
        """
        return self._reputations

    @reputations.setter
    def reputations(self, reputations):
        """Sets the reputations of this Entry.

        EntryReputations the reputations calculated by regex match  # noqa: E501

        :param reputations: The reputations of this Entry.  # noqa: E501
        :type: list[EntryReputation]
        """

        self._reputations = reputations

    @property
    def roles(self):
        """Gets the roles of this Entry.  # noqa: E501

        The role assigned to this investigation  # noqa: E501

        :return: The roles of this Entry.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this Entry.

        The role assigned to this investigation  # noqa: E501

        :param roles: The roles of this Entry.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def scheduled(self):
        """Gets the scheduled of this Entry.  # noqa: E501

        is it scheduled  # noqa: E501

        :return: The scheduled of this Entry.  # noqa: E501
        :rtype: bool
        """
        return self._scheduled

    @scheduled.setter
    def scheduled(self, scheduled):
        """Sets the scheduled of this Entry.

        is it scheduled  # noqa: E501

        :param scheduled: The scheduled of this Entry.  # noqa: E501
        :type: bool
        """

        self._scheduled = scheduled

    @property
    def sort_values(self):
        """Gets the sort_values of this Entry.  # noqa: E501


        :return: The sort_values of this Entry.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Entry.


        :param sort_values: The sort_values of this Entry.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def start_date(self):
        """Gets the start_date of this Entry.  # noqa: E501


        :return: The start_date of this Entry.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Entry.


        :param start_date: The start_date of this Entry.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def system(self):
        """Gets the system of this Entry.  # noqa: E501

        The name of the system associated with this entry  # noqa: E501

        :return: The system of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this Entry.

        The name of the system associated with this entry  # noqa: E501

        :param system: The system of this Entry.  # noqa: E501
        :type: str
        """

        self._system = system

    @property
    def tags(self):
        """Gets the tags of this Entry.  # noqa: E501

        Tags  # noqa: E501

        :return: The tags of this Entry.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Entry.

        Tags  # noqa: E501

        :param tags: The tags of this Entry.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def tags_raw(self):
        """Gets the tags_raw of this Entry.  # noqa: E501

        TagsRaw  # noqa: E501

        :return: The tags_raw of this Entry.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags_raw

    @tags_raw.setter
    def tags_raw(self, tags_raw):
        """Sets the tags_raw of this Entry.

        TagsRaw  # noqa: E501

        :param tags_raw: The tags_raw of this Entry.  # noqa: E501
        :type: list[str]
        """

        self._tags_raw = tags_raw

    @property
    def task_id(self):
        """Gets the task_id of this Entry.  # noqa: E501

        TaskID - used if the entry is assigned as note to a playbook task  # noqa: E501

        :return: The task_id of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this Entry.

        TaskID - used if the entry is assigned as note to a playbook task  # noqa: E501

        :param task_id: The task_id of this Entry.  # noqa: E501
        :type: str
        """

        self._task_id = task_id

    @property
    def times(self):
        """Gets the times of this Entry.  # noqa: E501


        :return: The times of this Entry.  # noqa: E501
        :rtype: int
        """
        return self._times

    @times.setter
    def times(self, times):
        """Sets the times of this Entry.


        :param times: The times of this Entry.  # noqa: E501
        :type: int
        """

        self._times = times

    @property
    def timezone_offset(self):
        """Gets the timezone_offset of this Entry.  # noqa: E501


        :return: The timezone_offset of this Entry.  # noqa: E501
        :rtype: int
        """
        return self._timezone_offset

    @timezone_offset.setter
    def timezone_offset(self, timezone_offset):
        """Sets the timezone_offset of this Entry.


        :param timezone_offset: The timezone_offset of this Entry.  # noqa: E501
        :type: int
        """

        self._timezone_offset = timezone_offset

    @property
    def type(self):
        """Gets the type of this Entry.  # noqa: E501


        :return: The type of this Entry.  # noqa: E501
        :rtype: EntryType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Entry.


        :param type: The type of this Entry.  # noqa: E501
        :type: EntryType
        """

        self._type = type

    @property
    def user(self):
        """Gets the user of this Entry.  # noqa: E501

        The user who created  the entry  # noqa: E501

        :return: The user of this Entry.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Entry.

        The user who created  the entry  # noqa: E501

        :param user: The user of this Entry.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def version(self):
        """Gets the version of this Entry.  # noqa: E501


        :return: The version of this Entry.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Entry.


        :param version: The version of this Entry.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Entry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Entry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SectionItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'object',
        'display_type': 'str',
        'end_col': 'int',
        'field_id': 'str',
        'field_name': 'str',
        'field_type': 'str',
        'header_style': 'object',
        'index': 'int',
        'start_col': 'int'
    }

    attribute_map = {
        'data': 'data',
        'display_type': 'displayType',
        'end_col': 'endCol',
        'field_id': 'fieldId',
        'field_name': 'fieldName',
        'field_type': 'fieldType',
        'header_style': 'headerStyle',
        'index': 'index',
        'start_col': 'startCol'
    }

    def __init__(self, data=None, display_type=None, end_col=None, field_id=None, field_name=None, field_type=None, header_style=None, index=None, start_col=None):  # noqa: E501
        """SectionItem - a model defined in Swagger"""  # noqa: E501

        self._data = None
        self._display_type = None
        self._end_col = None
        self._field_id = None
        self._field_name = None
        self._field_type = None
        self._header_style = None
        self._index = None
        self._start_col = None
        self.discriminator = None

        if data is not None:
            self.data = data
        if display_type is not None:
            self.display_type = display_type
        if end_col is not None:
            self.end_col = end_col
        if field_id is not None:
            self.field_id = field_id
        if field_name is not None:
            self.field_name = field_name
        if field_type is not None:
            self.field_type = field_type
        if header_style is not None:
            self.header_style = header_style
        if index is not None:
            self.index = index
        if start_col is not None:
            self.start_col = start_col

    @property
    def data(self):
        """Gets the data of this SectionItem.  # noqa: E501


        :return: The data of this SectionItem.  # noqa: E501
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this SectionItem.


        :param data: The data of this SectionItem.  # noqa: E501
        :type: object
        """

        self._data = data

    @property
    def display_type(self):
        """Gets the display_type of this SectionItem.  # noqa: E501


        :return: The display_type of this SectionItem.  # noqa: E501
        :rtype: str
        """
        return self._display_type

    @display_type.setter
    def display_type(self, display_type):
        """Sets the display_type of this SectionItem.


        :param display_type: The display_type of this SectionItem.  # noqa: E501
        :type: str
        """

        self._display_type = display_type

    @property
    def end_col(self):
        """Gets the end_col of this SectionItem.  # noqa: E501


        :return: The end_col of this SectionItem.  # noqa: E501
        :rtype: int
        """
        return self._end_col

    @end_col.setter
    def end_col(self, end_col):
        """Sets the end_col of this SectionItem.


        :param end_col: The end_col of this SectionItem.  # noqa: E501
        :type: int
        """

        self._end_col = end_col

    @property
    def field_id(self):
        """Gets the field_id of this SectionItem.  # noqa: E501


        :return: The field_id of this SectionItem.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this SectionItem.


        :param field_id: The field_id of this SectionItem.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def field_name(self):
        """Gets the field_name of this SectionItem.  # noqa: E501


        :return: The field_name of this SectionItem.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this SectionItem.


        :param field_name: The field_name of this SectionItem.  # noqa: E501
        :type: str
        """

        self._field_name = field_name

    @property
    def field_type(self):
        """Gets the field_type of this SectionItem.  # noqa: E501


        :return: The field_type of this SectionItem.  # noqa: E501
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """Sets the field_type of this SectionItem.


        :param field_type: The field_type of this SectionItem.  # noqa: E501
        :type: str
        """

        self._field_type = field_type

    @property
    def header_style(self):
        """Gets the header_style of this SectionItem.  # noqa: E501


        :return: The header_style of this SectionItem.  # noqa: E501
        :rtype: object
        """
        return self._header_style

    @header_style.setter
    def header_style(self, header_style):
        """Sets the header_style of this SectionItem.


        :param header_style: The header_style of this SectionItem.  # noqa: E501
        :type: object
        """

        self._header_style = header_style

    @property
    def index(self):
        """Gets the index of this SectionItem.  # noqa: E501


        :return: The index of this SectionItem.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this SectionItem.


        :param index: The index of this SectionItem.  # noqa: E501
        :type: int
        """

        self._index = index

    @property
    def start_col(self):
        """Gets the start_col of this SectionItem.  # noqa: E501


        :return: The start_col of this SectionItem.  # noqa: E501
        :rtype: int
        """
        return self._start_col

    @start_col.setter
    def start_col(self, start_col):
        """Sets the start_col of this SectionItem.


        :param start_col: The start_col of this SectionItem.  # noqa: E501
        :type: int
        """

        self._start_col = start_col

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SectionItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SectionItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.layout_field import LayoutField  # noqa: F401,E501


class LayoutSection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'fields': 'list[LayoutField]',
        'id': 'str',
        'is_visible': 'bool',
        'modified': 'datetime',
        'name': 'str',
        'primary_term': 'int',
        'query': 'object',
        'query_type': 'str',
        'read_only': 'bool',
        'sequence_number': 'int',
        'sort_values': 'list[str]',
        'type': 'str',
        'version': 'int'
    }

    attribute_map = {
        'description': 'description',
        'fields': 'fields',
        'id': 'id',
        'is_visible': 'isVisible',
        'modified': 'modified',
        'name': 'name',
        'primary_term': 'primaryTerm',
        'query': 'query',
        'query_type': 'queryType',
        'read_only': 'readOnly',
        'sequence_number': 'sequenceNumber',
        'sort_values': 'sortValues',
        'type': 'type',
        'version': 'version'
    }

    def __init__(self, description=None, fields=None, id=None, is_visible=None, modified=None, name=None, primary_term=None, query=None, query_type=None, read_only=None, sequence_number=None, sort_values=None, type=None, version=None):  # noqa: E501
        """LayoutSection - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._fields = None
        self._id = None
        self._is_visible = None
        self._modified = None
        self._name = None
        self._primary_term = None
        self._query = None
        self._query_type = None
        self._read_only = None
        self._sequence_number = None
        self._sort_values = None
        self._type = None
        self._version = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if fields is not None:
            self.fields = fields
        if id is not None:
            self.id = id
        if is_visible is not None:
            self.is_visible = is_visible
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if primary_term is not None:
            self.primary_term = primary_term
        if query is not None:
            self.query = query
        if query_type is not None:
            self.query_type = query_type
        if read_only is not None:
            self.read_only = read_only
        if sequence_number is not None:
            self.sequence_number = sequence_number
        if sort_values is not None:
            self.sort_values = sort_values
        if type is not None:
            self.type = type
        if version is not None:
            self.version = version

    @property
    def description(self):
        """Gets the description of this LayoutSection.  # noqa: E501


        :return: The description of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this LayoutSection.


        :param description: The description of this LayoutSection.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def fields(self):
        """Gets the fields of this LayoutSection.  # noqa: E501


        :return: The fields of this LayoutSection.  # noqa: E501
        :rtype: list[LayoutField]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this LayoutSection.


        :param fields: The fields of this LayoutSection.  # noqa: E501
        :type: list[LayoutField]
        """

        self._fields = fields

    @property
    def id(self):
        """Gets the id of this LayoutSection.  # noqa: E501


        :return: The id of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LayoutSection.


        :param id: The id of this LayoutSection.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_visible(self):
        """Gets the is_visible of this LayoutSection.  # noqa: E501


        :return: The is_visible of this LayoutSection.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible

    @is_visible.setter
    def is_visible(self, is_visible):
        """Sets the is_visible of this LayoutSection.


        :param is_visible: The is_visible of this LayoutSection.  # noqa: E501
        :type: bool
        """

        self._is_visible = is_visible

    @property
    def modified(self):
        """Gets the modified of this LayoutSection.  # noqa: E501


        :return: The modified of this LayoutSection.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this LayoutSection.


        :param modified: The modified of this LayoutSection.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this LayoutSection.  # noqa: E501


        :return: The name of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LayoutSection.


        :param name: The name of this LayoutSection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def primary_term(self):
        """Gets the primary_term of this LayoutSection.  # noqa: E501


        :return: The primary_term of this LayoutSection.  # noqa: E501
        :rtype: int
        """
        return self._primary_term

    @primary_term.setter
    def primary_term(self, primary_term):
        """Sets the primary_term of this LayoutSection.


        :param primary_term: The primary_term of this LayoutSection.  # noqa: E501
        :type: int
        """

        self._primary_term = primary_term

    @property
    def query(self):
        """Gets the query of this LayoutSection.  # noqa: E501


        :return: The query of this LayoutSection.  # noqa: E501
        :rtype: object
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this LayoutSection.


        :param query: The query of this LayoutSection.  # noqa: E501
        :type: object
        """

        self._query = query

    @property
    def query_type(self):
        """Gets the query_type of this LayoutSection.  # noqa: E501


        :return: The query_type of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._query_type

    @query_type.setter
    def query_type(self, query_type):
        """Sets the query_type of this LayoutSection.


        :param query_type: The query_type of this LayoutSection.  # noqa: E501
        :type: str
        """

        self._query_type = query_type

    @property
    def read_only(self):
        """Gets the read_only of this LayoutSection.  # noqa: E501


        :return: The read_only of this LayoutSection.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this LayoutSection.


        :param read_only: The read_only of this LayoutSection.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def sequence_number(self):
        """Gets the sequence_number of this LayoutSection.  # noqa: E501


        :return: The sequence_number of this LayoutSection.  # noqa: E501
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this LayoutSection.


        :param sequence_number: The sequence_number of this LayoutSection.  # noqa: E501
        :type: int
        """

        self._sequence_number = sequence_number

    @property
    def sort_values(self):
        """Gets the sort_values of this LayoutSection.  # noqa: E501


        :return: The sort_values of this LayoutSection.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this LayoutSection.


        :param sort_values: The sort_values of this LayoutSection.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def type(self):
        """Gets the type of this LayoutSection.  # noqa: E501


        :return: The type of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this LayoutSection.


        :param type: The type of this LayoutSection.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def version(self):
        """Gets the version of this LayoutSection.  # noqa: E501


        :return: The version of this LayoutSection.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this LayoutSection.


        :param version: The version of this LayoutSection.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LayoutSection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LayoutSection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.order import Order  # noqa: F401,E501


class AutomationScriptFilter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cache': 'dict(str, list[str])',
        'page': 'int',
        'query': 'str',
        'search_after': 'list[str]',
        'search_before': 'list[str]',
        'size': 'int',
        'sort': 'list[Order]',
        'strip_context': 'bool'
    }

    attribute_map = {
        'cache': 'Cache',
        'page': 'page',
        'query': 'query',
        'search_after': 'searchAfter',
        'search_before': 'searchBefore',
        'size': 'size',
        'sort': 'sort',
        'strip_context': 'stripContext'
    }

    def __init__(self, cache=None, page=None, query=None, search_after=None, search_before=None, size=None, sort=None, strip_context=None):  # noqa: E501
        """AutomationScriptFilter - a model defined in Swagger"""  # noqa: E501

        self._cache = None
        self._page = None
        self._query = None
        self._search_after = None
        self._search_before = None
        self._size = None
        self._sort = None
        self._strip_context = None
        self.discriminator = None

        if cache is not None:
            self.cache = cache
        if page is not None:
            self.page = page
        if query is not None:
            self.query = query
        if search_after is not None:
            self.search_after = search_after
        if search_before is not None:
            self.search_before = search_before
        if size is not None:
            self.size = size
        if sort is not None:
            self.sort = sort
        if strip_context is not None:
            self.strip_context = strip_context

    @property
    def cache(self):
        """Gets the cache of this AutomationScriptFilter.  # noqa: E501

        Cache of join functions  # noqa: E501

        :return: The cache of this AutomationScriptFilter.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this AutomationScriptFilter.

        Cache of join functions  # noqa: E501

        :param cache: The cache of this AutomationScriptFilter.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._cache = cache

    @property
    def page(self):
        """Gets the page of this AutomationScriptFilter.  # noqa: E501

        0-based page  # noqa: E501

        :return: The page of this AutomationScriptFilter.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this AutomationScriptFilter.

        0-based page  # noqa: E501

        :param page: The page of this AutomationScriptFilter.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def query(self):
        """Gets the query of this AutomationScriptFilter.  # noqa: E501


        :return: The query of this AutomationScriptFilter.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this AutomationScriptFilter.


        :param query: The query of this AutomationScriptFilter.  # noqa: E501
        :type: str
        """

        self._query = query

    @property
    def search_after(self):
        """Gets the search_after of this AutomationScriptFilter.  # noqa: E501

        Efficient next page, pass max sort value from previous page  # noqa: E501

        :return: The search_after of this AutomationScriptFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._search_after

    @search_after.setter
    def search_after(self, search_after):
        """Sets the search_after of this AutomationScriptFilter.

        Efficient next page, pass max sort value from previous page  # noqa: E501

        :param search_after: The search_after of this AutomationScriptFilter.  # noqa: E501
        :type: list[str]
        """

        self._search_after = search_after

    @property
    def search_before(self):
        """Gets the search_before of this AutomationScriptFilter.  # noqa: E501

        Efficient prev page, pass min sort value from next page  # noqa: E501

        :return: The search_before of this AutomationScriptFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._search_before

    @search_before.setter
    def search_before(self, search_before):
        """Sets the search_before of this AutomationScriptFilter.

        Efficient prev page, pass min sort value from next page  # noqa: E501

        :param search_before: The search_before of this AutomationScriptFilter.  # noqa: E501
        :type: list[str]
        """

        self._search_before = search_before

    @property
    def size(self):
        """Gets the size of this AutomationScriptFilter.  # noqa: E501

        Size is limited to 1000, if not passed it defaults to 0, and no results will return  # noqa: E501

        :return: The size of this AutomationScriptFilter.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this AutomationScriptFilter.

        Size is limited to 1000, if not passed it defaults to 0, and no results will return  # noqa: E501

        :param size: The size of this AutomationScriptFilter.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def sort(self):
        """Gets the sort of this AutomationScriptFilter.  # noqa: E501

        The sort order  # noqa: E501

        :return: The sort of this AutomationScriptFilter.  # noqa: E501
        :rtype: list[Order]
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this AutomationScriptFilter.

        The sort order  # noqa: E501

        :param sort: The sort of this AutomationScriptFilter.  # noqa: E501
        :type: list[Order]
        """

        self._sort = sort

    @property
    def strip_context(self):
        """Gets the strip_context of this AutomationScriptFilter.  # noqa: E501


        :return: The strip_context of this AutomationScriptFilter.  # noqa: E501
        :rtype: bool
        """
        return self._strip_context

    @strip_context.setter
    def strip_context(self, strip_context):
        """Sets the strip_context of this AutomationScriptFilter.


        :param strip_context: The strip_context of this AutomationScriptFilter.  # noqa: E501
        :type: bool
        """

        self._strip_context = strip_context

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AutomationScriptFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AutomationScriptFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.custom_fields import CustomFields  # noqa: F401,E501
from demisto_client.demisto_api.models.expiration_policy import ExpirationPolicy  # noqa: F401,E501
from demisto_client.demisto_api.models.expiration_source import ExpirationSource  # noqa: F401,E501
from demisto_client.demisto_api.models.reliability import Reliability  # noqa: F401,E501


class FeedIndicator(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'expiration_source': 'ExpirationSource',
        'bypass_exclusion_list': 'bool',
        'classifier_version': 'int',
        'expiration_interval': 'int',
        'expiration_policy': 'ExpirationPolicy',
        'feed_config': 'dict(str, object)',
        'fetch_time': 'datetime',
        'fields': 'CustomFields',
        'is_enrichment': 'bool',
        'modified_time': 'datetime',
        'module_id': 'str',
        'raw_json': 'dict(str, object)',
        'reliability': 'Reliability',
        'score': 'int',
        'source_brand': 'str',
        'source_instance': 'str',
        'timestamp': 'datetime',
        'type': 'str',
        'value': 'str'
    }

    attribute_map = {
        'expiration_source': 'ExpirationSource',
        'bypass_exclusion_list': 'bypassExclusionList',
        'classifier_version': 'classifierVersion',
        'expiration_interval': 'expirationInterval',
        'expiration_policy': 'expirationPolicy',
        'feed_config': 'feedConfig',
        'fetch_time': 'fetchTime',
        'fields': 'fields',
        'is_enrichment': 'isEnrichment',
        'modified_time': 'modifiedTime',
        'module_id': 'moduleId',
        'raw_json': 'rawJSON',
        'reliability': 'reliability',
        'score': 'score',
        'source_brand': 'sourceBrand',
        'source_instance': 'sourceInstance',
        'timestamp': 'timestamp',
        'type': 'type',
        'value': 'value'
    }

    def __init__(self, expiration_source=None, bypass_exclusion_list=None, classifier_version=None, expiration_interval=None, expiration_policy=None, feed_config=None, fetch_time=None, fields=None, is_enrichment=None, modified_time=None, module_id=None, raw_json=None, reliability=None, score=None, source_brand=None, source_instance=None, timestamp=None, type=None, value=None):  # noqa: E501
        """FeedIndicator - a model defined in Swagger"""  # noqa: E501

        self._expiration_source = None
        self._bypass_exclusion_list = None
        self._classifier_version = None
        self._expiration_interval = None
        self._expiration_policy = None
        self._feed_config = None
        self._fetch_time = None
        self._fields = None
        self._is_enrichment = None
        self._modified_time = None
        self._module_id = None
        self._raw_json = None
        self._reliability = None
        self._score = None
        self._source_brand = None
        self._source_instance = None
        self._timestamp = None
        self._type = None
        self._value = None
        self.discriminator = None

        if expiration_source is not None:
            self.expiration_source = expiration_source
        if bypass_exclusion_list is not None:
            self.bypass_exclusion_list = bypass_exclusion_list
        if classifier_version is not None:
            self.classifier_version = classifier_version
        if expiration_interval is not None:
            self.expiration_interval = expiration_interval
        if expiration_policy is not None:
            self.expiration_policy = expiration_policy
        if feed_config is not None:
            self.feed_config = feed_config
        if fetch_time is not None:
            self.fetch_time = fetch_time
        if fields is not None:
            self.fields = fields
        if is_enrichment is not None:
            self.is_enrichment = is_enrichment
        if modified_time is not None:
            self.modified_time = modified_time
        if module_id is not None:
            self.module_id = module_id
        if raw_json is not None:
            self.raw_json = raw_json
        if reliability is not None:
            self.reliability = reliability
        if score is not None:
            self.score = score
        if source_brand is not None:
            self.source_brand = source_brand
        if source_instance is not None:
            self.source_instance = source_instance
        if timestamp is not None:
            self.timestamp = timestamp
        if type is not None:
            self.type = type
        if value is not None:
            self.value = value

    @property
    def expiration_source(self):
        """Gets the expiration_source of this FeedIndicator.  # noqa: E501


        :return: The expiration_source of this FeedIndicator.  # noqa: E501
        :rtype: ExpirationSource
        """
        return self._expiration_source

    @expiration_source.setter
    def expiration_source(self, expiration_source):
        """Sets the expiration_source of this FeedIndicator.


        :param expiration_source: The expiration_source of this FeedIndicator.  # noqa: E501
        :type: ExpirationSource
        """

        self._expiration_source = expiration_source

    @property
    def bypass_exclusion_list(self):
        """Gets the bypass_exclusion_list of this FeedIndicator.  # noqa: E501


        :return: The bypass_exclusion_list of this FeedIndicator.  # noqa: E501
        :rtype: bool
        """
        return self._bypass_exclusion_list

    @bypass_exclusion_list.setter
    def bypass_exclusion_list(self, bypass_exclusion_list):
        """Sets the bypass_exclusion_list of this FeedIndicator.


        :param bypass_exclusion_list: The bypass_exclusion_list of this FeedIndicator.  # noqa: E501
        :type: bool
        """

        self._bypass_exclusion_list = bypass_exclusion_list

    @property
    def classifier_version(self):
        """Gets the classifier_version of this FeedIndicator.  # noqa: E501


        :return: The classifier_version of this FeedIndicator.  # noqa: E501
        :rtype: int
        """
        return self._classifier_version

    @classifier_version.setter
    def classifier_version(self, classifier_version):
        """Sets the classifier_version of this FeedIndicator.


        :param classifier_version: The classifier_version of this FeedIndicator.  # noqa: E501
        :type: int
        """

        self._classifier_version = classifier_version

    @property
    def expiration_interval(self):
        """Gets the expiration_interval of this FeedIndicator.  # noqa: E501


        :return: The expiration_interval of this FeedIndicator.  # noqa: E501
        :rtype: int
        """
        return self._expiration_interval

    @expiration_interval.setter
    def expiration_interval(self, expiration_interval):
        """Sets the expiration_interval of this FeedIndicator.


        :param expiration_interval: The expiration_interval of this FeedIndicator.  # noqa: E501
        :type: int
        """

        self._expiration_interval = expiration_interval

    @property
    def expiration_policy(self):
        """Gets the expiration_policy of this FeedIndicator.  # noqa: E501


        :return: The expiration_policy of this FeedIndicator.  # noqa: E501
        :rtype: ExpirationPolicy
        """
        return self._expiration_policy

    @expiration_policy.setter
    def expiration_policy(self, expiration_policy):
        """Sets the expiration_policy of this FeedIndicator.


        :param expiration_policy: The expiration_policy of this FeedIndicator.  # noqa: E501
        :type: ExpirationPolicy
        """

        self._expiration_policy = expiration_policy

    @property
    def feed_config(self):
        """Gets the feed_config of this FeedIndicator.  # noqa: E501


        :return: The feed_config of this FeedIndicator.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._feed_config

    @feed_config.setter
    def feed_config(self, feed_config):
        """Sets the feed_config of this FeedIndicator.


        :param feed_config: The feed_config of this FeedIndicator.  # noqa: E501
        :type: dict(str, object)
        """

        self._feed_config = feed_config

    @property
    def fetch_time(self):
        """Gets the fetch_time of this FeedIndicator.  # noqa: E501


        :return: The fetch_time of this FeedIndicator.  # noqa: E501
        :rtype: datetime
        """
        return self._fetch_time

    @fetch_time.setter
    def fetch_time(self, fetch_time):
        """Sets the fetch_time of this FeedIndicator.


        :param fetch_time: The fetch_time of this FeedIndicator.  # noqa: E501
        :type: datetime
        """

        self._fetch_time = fetch_time

    @property
    def fields(self):
        """Gets the fields of this FeedIndicator.  # noqa: E501


        :return: The fields of this FeedIndicator.  # noqa: E501
        :rtype: CustomFields
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this FeedIndicator.


        :param fields: The fields of this FeedIndicator.  # noqa: E501
        :type: CustomFields
        """

        self._fields = fields

    @property
    def is_enrichment(self):
        """Gets the is_enrichment of this FeedIndicator.  # noqa: E501


        :return: The is_enrichment of this FeedIndicator.  # noqa: E501
        :rtype: bool
        """
        return self._is_enrichment

    @is_enrichment.setter
    def is_enrichment(self, is_enrichment):
        """Sets the is_enrichment of this FeedIndicator.


        :param is_enrichment: The is_enrichment of this FeedIndicator.  # noqa: E501
        :type: bool
        """

        self._is_enrichment = is_enrichment

    @property
    def modified_time(self):
        """Gets the modified_time of this FeedIndicator.  # noqa: E501


        :return: The modified_time of this FeedIndicator.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_time

    @modified_time.setter
    def modified_time(self, modified_time):
        """Sets the modified_time of this FeedIndicator.


        :param modified_time: The modified_time of this FeedIndicator.  # noqa: E501
        :type: datetime
        """

        self._modified_time = modified_time

    @property
    def module_id(self):
        """Gets the module_id of this FeedIndicator.  # noqa: E501


        :return: The module_id of this FeedIndicator.  # noqa: E501
        :rtype: str
        """
        return self._module_id

    @module_id.setter
    def module_id(self, module_id):
        """Sets the module_id of this FeedIndicator.


        :param module_id: The module_id of this FeedIndicator.  # noqa: E501
        :type: str
        """

        self._module_id = module_id

    @property
    def raw_json(self):
        """Gets the raw_json of this FeedIndicator.  # noqa: E501


        :return: The raw_json of this FeedIndicator.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._raw_json

    @raw_json.setter
    def raw_json(self, raw_json):
        """Sets the raw_json of this FeedIndicator.


        :param raw_json: The raw_json of this FeedIndicator.  # noqa: E501
        :type: dict(str, object)
        """

        self._raw_json = raw_json

    @property
    def reliability(self):
        """Gets the reliability of this FeedIndicator.  # noqa: E501


        :return: The reliability of this FeedIndicator.  # noqa: E501
        :rtype: Reliability
        """
        return self._reliability

    @reliability.setter
    def reliability(self, reliability):
        """Sets the reliability of this FeedIndicator.


        :param reliability: The reliability of this FeedIndicator.  # noqa: E501
        :type: Reliability
        """

        self._reliability = reliability

    @property
    def score(self):
        """Gets the score of this FeedIndicator.  # noqa: E501


        :return: The score of this FeedIndicator.  # noqa: E501
        :rtype: int
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this FeedIndicator.


        :param score: The score of this FeedIndicator.  # noqa: E501
        :type: int
        """

        self._score = score

    @property
    def source_brand(self):
        """Gets the source_brand of this FeedIndicator.  # noqa: E501


        :return: The source_brand of this FeedIndicator.  # noqa: E501
        :rtype: str
        """
        return self._source_brand

    @source_brand.setter
    def source_brand(self, source_brand):
        """Sets the source_brand of this FeedIndicator.


        :param source_brand: The source_brand of this FeedIndicator.  # noqa: E501
        :type: str
        """

        self._source_brand = source_brand

    @property
    def source_instance(self):
        """Gets the source_instance of this FeedIndicator.  # noqa: E501


        :return: The source_instance of this FeedIndicator.  # noqa: E501
        :rtype: str
        """
        return self._source_instance

    @source_instance.setter
    def source_instance(self, source_instance):
        """Sets the source_instance of this FeedIndicator.


        :param source_instance: The source_instance of this FeedIndicator.  # noqa: E501
        :type: str
        """

        self._source_instance = source_instance

    @property
    def timestamp(self):
        """Gets the timestamp of this FeedIndicator.  # noqa: E501


        :return: The timestamp of this FeedIndicator.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this FeedIndicator.


        :param timestamp: The timestamp of this FeedIndicator.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    @property
    def type(self):
        """Gets the type of this FeedIndicator.  # noqa: E501

        indicator fields  # noqa: E501

        :return: The type of this FeedIndicator.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FeedIndicator.

        indicator fields  # noqa: E501

        :param type: The type of this FeedIndicator.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def value(self):
        """Gets the value of this FeedIndicator.  # noqa: E501


        :return: The value of this FeedIndicator.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this FeedIndicator.


        :param value: The value of this FeedIndicator.  # noqa: E501
        :type: str
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeedIndicator, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedIndicator):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class HumanCron(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'at_time_hour': 'str',
        'at_time_minute': 'str',
        'days': 'list[str]',
        'hours_period': 'str',
        'scheduling_type': 'str',
        'time_period': 'int',
        'time_period_type': 'str'
    }

    attribute_map = {
        'at_time_hour': 'atTimeHour',
        'at_time_minute': 'atTimeMinute',
        'days': 'days',
        'hours_period': 'hoursPeriod',
        'scheduling_type': 'schedulingType',
        'time_period': 'timePeriod',
        'time_period_type': 'timePeriodType'
    }

    def __init__(self, at_time_hour=None, at_time_minute=None, days=None, hours_period=None, scheduling_type=None, time_period=None, time_period_type=None):  # noqa: E501
        """HumanCron - a model defined in Swagger"""  # noqa: E501

        self._at_time_hour = None
        self._at_time_minute = None
        self._days = None
        self._hours_period = None
        self._scheduling_type = None
        self._time_period = None
        self._time_period_type = None
        self.discriminator = None

        if at_time_hour is not None:
            self.at_time_hour = at_time_hour
        if at_time_minute is not None:
            self.at_time_minute = at_time_minute
        if days is not None:
            self.days = days
        if hours_period is not None:
            self.hours_period = hours_period
        if scheduling_type is not None:
            self.scheduling_type = scheduling_type
        if time_period is not None:
            self.time_period = time_period
        if time_period_type is not None:
            self.time_period_type = time_period_type

    @property
    def at_time_hour(self):
        """Gets the at_time_hour of this HumanCron.  # noqa: E501


        :return: The at_time_hour of this HumanCron.  # noqa: E501
        :rtype: str
        """
        return self._at_time_hour

    @at_time_hour.setter
    def at_time_hour(self, at_time_hour):
        """Sets the at_time_hour of this HumanCron.


        :param at_time_hour: The at_time_hour of this HumanCron.  # noqa: E501
        :type: str
        """

        self._at_time_hour = at_time_hour

    @property
    def at_time_minute(self):
        """Gets the at_time_minute of this HumanCron.  # noqa: E501


        :return: The at_time_minute of this HumanCron.  # noqa: E501
        :rtype: str
        """
        return self._at_time_minute

    @at_time_minute.setter
    def at_time_minute(self, at_time_minute):
        """Sets the at_time_minute of this HumanCron.


        :param at_time_minute: The at_time_minute of this HumanCron.  # noqa: E501
        :type: str
        """

        self._at_time_minute = at_time_minute

    @property
    def days(self):
        """Gets the days of this HumanCron.  # noqa: E501


        :return: The days of this HumanCron.  # noqa: E501
        :rtype: list[str]
        """
        return self._days

    @days.setter
    def days(self, days):
        """Sets the days of this HumanCron.


        :param days: The days of this HumanCron.  # noqa: E501
        :type: list[str]
        """

        self._days = days

    @property
    def hours_period(self):
        """Gets the hours_period of this HumanCron.  # noqa: E501


        :return: The hours_period of this HumanCron.  # noqa: E501
        :rtype: str
        """
        return self._hours_period

    @hours_period.setter
    def hours_period(self, hours_period):
        """Sets the hours_period of this HumanCron.


        :param hours_period: The hours_period of this HumanCron.  # noqa: E501
        :type: str
        """

        self._hours_period = hours_period

    @property
    def scheduling_type(self):
        """Gets the scheduling_type of this HumanCron.  # noqa: E501

        the following fields are deprecated. do not use them.  # noqa: E501

        :return: The scheduling_type of this HumanCron.  # noqa: E501
        :rtype: str
        """
        return self._scheduling_type

    @scheduling_type.setter
    def scheduling_type(self, scheduling_type):
        """Sets the scheduling_type of this HumanCron.

        the following fields are deprecated. do not use them.  # noqa: E501

        :param scheduling_type: The scheduling_type of this HumanCron.  # noqa: E501
        :type: str
        """

        self._scheduling_type = scheduling_type

    @property
    def time_period(self):
        """Gets the time_period of this HumanCron.  # noqa: E501


        :return: The time_period of this HumanCron.  # noqa: E501
        :rtype: int
        """
        return self._time_period

    @time_period.setter
    def time_period(self, time_period):
        """Sets the time_period of this HumanCron.


        :param time_period: The time_period of this HumanCron.  # noqa: E501
        :type: int
        """

        self._time_period = time_period

    @property
    def time_period_type(self):
        """Gets the time_period_type of this HumanCron.  # noqa: E501


        :return: The time_period_type of this HumanCron.  # noqa: E501
        :rtype: str
        """
        return self._time_period_type

    @time_period_type.setter
    def time_period_type(self, time_period_type):
        """Sets the time_period_type of this HumanCron.


        :param time_period_type: The time_period_type of this HumanCron.  # noqa: E501
        :type: str
        """

        self._time_period_type = time_period_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HumanCron, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HumanCron):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
